/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2005-2006 EBM WebSourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.jbi.descriptor;

import org.apache.commons.lang.builder.EqualsBuilder;
import org.apache.commons.lang.builder.HashCodeBuilder;
import org.apache.commons.lang.builder.ToStringBuilder;
import org.w3c.dom.Document;
import org.w3c.dom.Node;

/**
 * 
 * @author ofabre
 * 
 */
public class ExtensibleJbiElement {

    private Extensions extensions;

    public ExtensibleJbiElement() {
        super();
    }

    /*
     * (non-Javadoc)
     * @see java.lang.Object#equals(java.lang.Object)
     */
    @Override
    public boolean equals(final Object other) {
        boolean bRet;
        if (other instanceof ExtensibleJbiElement) {
            final ExtensibleJbiElement castOther = (ExtensibleJbiElement) other;
            bRet = new EqualsBuilder().append(this.extensions, castOther.extensions).isEquals();
        } else {
            bRet = false;
        }

        return bRet;
    }

    /*
     * (non-Javadoc)
     * @see java.lang.Object#hashCode()
     */
    @Override
    public int hashCode() {
        return new HashCodeBuilder().append(this.extensions).toHashCode();
    }

    /*
     * (non-Javadoc)
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        return new ToStringBuilder(this).append("extensions", this.extensions).toString();
    }

    /**
     * Generate a XML representation of the extension descriptor node
     * 
     * @return the XML representation
     */
    public Node getNode(final Document jbiDescriptorDocument) {
        return this.extensions.getNode(jbiDescriptorDocument);
    }

    public final Extensions getExtensions() {
        return this.extensions;
    }

    public final void setExtensions(final Extensions extensions) {
        this.extensions = extensions;
    }
}
